from eda_report.cli import run_from_cli

if __name__ == "__main__":
    run_from_cli()
